tgraph

package
v0.0.0-...-ec27be8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FetchHTML

func FetchHTML(rawLink string) (string, error)

FetchHTML fetches content from the unrender service and returns it as HTML suitable for Telegraph's CreatePageWithHTML. The unrender service returns markdown, which is converted to HTML via goldmark.

func PublishHtml

func PublishHtml(sourceTitle string, title string, rawLink string, htmlContent string) (string, error)

Types

This section is empty.

Jump to